.. WireTransfers documentation master file, created by
   sphinx-quickstart on Thu Sep 13 07:37:27 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

WireTransfers's documentation!
==============================

Release v\ |version|.

WireTransfers is an :ref:`ISC Licensed <isc>`  online payments library,
written in Python, supporting various online payment protocols (IPizza,
Solo/TUPAS) using a simple API.

User Guide
----------

This part of documentation begins with some background information, then
focuses on step-by-step instructions for making online payments using
WireTransfers library.

.. toctree::
   :maxdepth: 2

   user/intro
   user/providers
   user/flask_quickstart

API Documentation
-----------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


Developer Guide
---------------

If you want to contribute to the project, this part of the documentation is
for you.

